# Beginner Start Here

Start with the workspace [README.md](../README.md).

It explains:

- how to create or activate `xenv`
- how to activate `xenv`
- how `scix up` or `scix dev` install `nvm`, Node.js/npm, Codex, and Claude
  when they are missing
- how to log into Codex and Claude
- what `repos/`, `workspace/`, and `ai/` are
- how to use `scix sync`
